@@ -390,35 +390,55 @@ GNUNET_DISK_file_handle_size (struct GNUNET_DISK_FileHandle *fh,
                               off_t *size);
 
 
+/**
+ * Flags for #GNUNET_DISK_pipe().
+ */
+enum GNUNET_DISK_PipeFlags
+{
+
+  /**
+   * No special options, use non-blocking read/write operations.
+   */
+  GNUNET_DISK_PF_NONE,
+
+  /**
+   * Configure read end to block when reading if set.
+   */
+  GNUNET_DISK_PF_BLOCKING_READ = 1,
+  /**
+   * Configure write end to block when writing if set.
+   */
+  GNUNET_DISK_PF_BLOCKING_WRITE = 2,
+
+  /**
+   * Configure both pipe ends for blocking operations if set.
+   */
+  GNUNET_DISK_PF_BLOCKING_RW = GNUNET_DISK_PF_BLOCKING_READ
+                               | GNUNET_DISK_PF_BLOCKING_WRITE
+
+};
+
+
 /**
  * Creates an interprocess channel
  *
- * @param blocking_read creates an asynchronous pipe for reading if set to #GNUNET_NO
- * @param blocking_write creates an asynchronous pipe for writing if set to #GNUNET_NO
- * @param inherit_read 1 to make read handle inheritable, 0 otherwise (NT only)
- * @param inherit_write 1 to make write handle inheritable, 0 otherwise (NT only)
+ * @param pf how to configure the pipe
  * @return handle to the new pipe, NULL on error
  */
 struct GNUNET_DISK_PipeHandle *
-GNUNET_DISK_pipe (int blocking_read,
-                  int blocking_write,
-                  int inherit_read,
-                  int inherit_write);
+GNUNET_DISK_pipe (enum GNUNET_DISK_PipeFlags pf);
 
 
 /**
  * Creates a pipe object from a couple of file descriptors.
  * Useful for wrapping existing pipe FDs.
  *
- * @param blocking_read creates an asynchronous pipe for reading if set to #GNUNET_NO
- * @param blocking_write creates an asynchronous pipe for writing if set to #GNUNET_NO
+ * @param pf how to configure the pipe
  * @param fd an array of two fd values. One of them may be -1 for read-only or write-only pipes
- *
  * @return handle to the new pipe, NULL on error
  */
 struct GNUNET_DISK_PipeHandle *
-GNUNET_DISK_pipe_from_fd (int blocking_read,
-                          int blocking_write,
+GNUNET_DISK_pipe_from_fd (enum GNUNET_DISK_PipeFlags pf,
                           int fd[2]);
 
 
@@ -480,6 +500,7 @@ const struct GNUNET_DISK_FileHandle *
 GNUNET_DISK_pipe_handle (const struct GNUNET_DISK_PipeHandle *p,
                          enum GNUNET_DISK_PipeEnd n);
 
+
 /**
  * Update POSIX permissions mask of a file on disk.  If both argumets
  * are #GNUNET_NO, the file is made world-read-write-executable (777).
@@ -691,35 +712,6 @@ int
 GNUNET_DISK_directory_create (const char *dir);
 
 
-/**
- * Lock a part of a file.
- *
- * @param fh file handle
- * @param lock_start absolute position from where to lock
- * @param lock_end absolute position until where to lock
- * @param excl #GNUNET_YES for an exclusive lock
- * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
- */
-int
-GNUNET_DISK_file_lock (struct GNUNET_DISK_FileHandle *fh,
-                       off_t lock_start,
-                       off_t lock_end, int excl);
-
-
-/**
- * Unlock a part of a file.
- *
- * @param fh file handle
- * @param unlock_start absolute position from where to unlock
- * @param unlock_end absolute position until where to unlock
- * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
- */
-int
-GNUNET_DISK_file_unlock (struct GNUNET_DISK_FileHandle *fh,
-                         off_t unlock_start,
-                         off_t unlock_end);
-
-
 /**
  * @brief Removes special characters as ':' from a filename.
  * @param fn the filename to canonicalize
